
clear; clc;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% parameter_setting %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% parameters
cbeta = 0.98;
calpha = 0.295;
cdelta = 0.06;
cphi = 6.7;
cpsi = 0.05;
ceta = 2.5;
clambda = 1.0522;
cG_0 = 0.1;

% initial policy params

etau_k = 0;

params = [cbeta,
          calpha,
          cdelta,
          cphi,
          cpsi,
          ceta,
          clambda,
          cG_0];
policy = [etau_k];

save('params.mat', 'params');
save('policy.mat', 'policy');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

compute_steadystate;

dynare model_initval.mod nostrict;



init_sim = oo_.dr.ys;
save('init_sim.mat', 'init_sim')

% new policy params
cap_tax_range = linspace(-0.5, 0.5, 50);
welfare_vec = NaN(numel(cap_tax_range), 2);
for i = 1:length(cap_tax_range)
    etau_k = cap_tax_range(i);
    policy = [etau_k];

    save('policy.mat', 'policy');

    compute_steadystate;
    dynare model_toloop.mod nostrict noclearall;

    %% evaluating welfare %%

    % position of variables
    p_k = find(M_.endo_names(oo_.dr.order_var) == 'k');;
    p_q = find(M_.endo_names(oo_.dr.order_var) == 'q');;
    p_c = find(M_.endo_names(oo_.dr.order_var) == 'c');;
    p_y = find(M_.endo_names(oo_.dr.order_var) == 'y');;
    p_l = find(M_.endo_names(oo_.dr.order_var) == 'l');;
    p_e = find(M_.endo_names(oo_.dr.order_var) == 'e');;


    % sequences for vars we care about
    c = tau_simul(p_c, :);
    l = tau_simul(p_l, :);
    q = tau_simul(p_q, :);

    c_dev = tau_simul(p_c, :) - oo_.dr.ys(p_c);
    l_dev = tau_simul(p_l, :) - oo_.dr.ys(p_l);
    q_dev = tau_simul(p_q, :) - oo_.dr.ys(p_q);

    tol = 1e-6;
    n_iter = sum(abs(c_dev) > tol);

    % generating series for A
    A_0 = 1;
    A_series = [A_0];
    for j = 1:n_iter
      A_1 = (q(j)) * A_0;
      A_series = [A_series, A_1];
      A_0 = A_1;
    end

    c_A = c(1:n_iter) .* A_series(1:n_iter);

    welfare_nbgp = [];
    for t = 1:n_iter
      util = cbeta^t * ( (log(c_A(t))) - cphi * ((l(t))^(1 + ceta))/(1 + ceta));
      welfare_nbgp = [welfare_nbgp, util];
    end
    welfare_nbgp_tot = sum(welfare_nbgp);

    util_bgp = log(c(1) * A_series(end))/(1 - cbeta) - (cbeta / (1 - cbeta)^2) * log(q(t+1) - 1) - ( (cphi * l(t+1)^(1 + ceta))/((1 - cbeta) * (1 - ceta)));
    welfare = welfare_nbgp_tot + util_bgp %just to check if welfare is going fine
    welfare_vec(i, 1) = etau_k;
    welfare_vec(i, 2) = welfare;
end


opttau_p = find(welfare_vec(:, 2) == max(welfare_vec(:, 2)));
optimal_tauk = welfare_vec(opttau_p, 1)
%}
